diff -ru zsh-3.1.5/Src/init.c zsh-3.1.5-mod/Src/init.c
--- zsh-3.1.5/Src/init.c	Mon Oct 12 01:01:03 1998
+++ zsh-3.1.5-mod/Src/init.c	Thu Mar 11 10:54:05 1999
@@ -743,7 +743,11 @@
 void
 init_misc(void)
 {
+#ifndef RESTRICTED_R
+    if ( restricted )
+#else
     if (*zsh_name == 'r' || restricted)
+#endif
 	dosetopt(RESTRICTED, 1, 0);
     if (cmd) {
 	if (SHIN >= 10)
diff -ru zsh-3.1.5/acconfig.h zsh-3.1.5-mod/acconfig.h
--- zsh-3.1.5/acconfig.h	Fri Oct 30 00:13:29 1998
+++ zsh-3.1.5-mod/acconfig.h	Thu Mar 11 11:31:03 1999
@@ -155,6 +155,11 @@
  * hash tables.  This turns on the `hashinfo' builtin.              */
 #undef ZSH_HASH_DEBUG
 
+/* Undefine this if you don't want to get a restricted shell *
+ * when zsh is exec'd with basename that starts with r.      *
+ * By default this is defined.                               */
+#undef RESTRICTED_R
+
 /* Define to 1 if your termcap library has the ospeed variable */
 #undef HAVE_OSPEED
 /* Define to 1 if you have ospeed, but it is not defined in termcap.h */
diff -ru zsh-3.1.5/config.h.in zsh-3.1.5-mod/config.h.in
--- zsh-3.1.5/config.h.in	Fri Oct 30 00:35:16 1998
+++ zsh-3.1.5-mod/config.h.in	Thu Mar 11 11:31:41 1999
@@ -219,6 +219,11 @@
  * hash tables.  This turns on the `hashinfo' builtin.              */
 #undef ZSH_HASH_DEBUG
 
+/* Undefine this if you don't want to get a restricted shell *
+ * when zsh is exec'd with basename that starts with r.      *
+ * By default this is defined.                               */
+#undef RESTRICTED_R
+
 /* Define to 1 if your termcap library has the ospeed variable */
 #undef HAVE_OSPEED
 /* Define to 1 if you have ospeed, but it is not defined in termcap.h */
diff -ru zsh-3.1.5/configure zsh-3.1.5-mod/configure
--- zsh-3.1.5/configure	Fri Oct 30 00:33:14 1998
+++ zsh-3.1.5-mod/configure	Thu Mar 11 11:31:52 1999
@@ -39,6 +39,8 @@
   --enable-dynamic           allow dynamically loaded binary modules"
 ac_help="$ac_help
   --enable-ansi2knr          translate source to K&R C before compiling"
+ac_help="$ac_help
+  --disable-resticted-r      turn off restricted shell if the invoked command is r*"
 
 # Initialize some variables set by options.
 # The variables have the same names as the options, with
@@ -577,7 +579,7 @@
 fi
 
 echo $ac_n "checking host system type""... $ac_c" 1>&6
-echo "configure:581: checking host system type" >&5
+echo "configure:583: checking host system type" >&5
 
 host_alias=$host
 case "$host_alias" in
@@ -805,13 +807,31 @@
 fi
 
 
+# Check whether --enable-resticted-r or --disable-resticted-r was given.
+if test "${enable_resticted_r+set}" = set; then
+  enableval="$enable_resticted_r"
+  if test x$enableval = xyes; then
+  cat >> confdefs.h <<\EOF
+#define RESTRICTED_R 1
+EOF
+
+fi
+else
+  cat >> confdefs.h <<\EOF
+#define RESTRICTED_R 1
+EOF
+
+
+fi
+
+
 test -z "${CFLAGS+set}"  && CFLAGS=  auto_cflags=1
 test -z "${LDFLAGS+set}" && LDFLAGS= auto_ldflags=1
 
 # Extract the first word of "gcc", so it can be a program name with args.
 set dummy gcc; ac_word=$2
 echo $ac_n "checking for $ac_word""... $ac_c" 1>&6
-echo "configure:815: checking for $ac_word" >&5
+echo "configure:835: checking for $ac_word" >&5
 if eval "test \"`echo '$''{'ac_cv_prog_CC'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
@@ -840,7 +860,7 @@
   # Extract the first word of "cc", so it can be a program name with args.
 set dummy cc; ac_word=$2
 echo $ac_n "checking for $ac_word""... $ac_c" 1>&6
-echo "configure:844: checking for $ac_word" >&5
+echo "configure:864: checking for $ac_word" >&5
 if eval "test \"`echo '$''{'ac_cv_prog_CC'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
@@ -888,7 +908,7 @@
 fi
 
 echo $ac_n "checking whether the C compiler ($CC $CFLAGS $LDFLAGS) works""... $ac_c" 1>&6
-echo "configure:892: checking whether the C compiler ($CC $CFLAGS $LDFLAGS) works" >&5
+echo "configure:912: checking whether the C compiler ($CC $CFLAGS $LDFLAGS) works" >&5
 
 ac_ext=c
 # CFLAGS is not in ac_cpp because -g, -O, etc. are not valid cpp options.
@@ -898,11 +918,11 @@
 cross_compiling=$ac_cv_prog_cc_cross
 
 cat > conftest.$ac_ext <<EOF
-#line 902 "configure"
+#line 922 "configure"
 #include "confdefs.h"
 main(){return(0);}
 EOF
-if { (eval echo configure:906: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
+if { (eval echo configure:926: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
   ac_cv_prog_cc_works=yes
   # If we can't run a trivial program, we are probably using a cross compiler.
   if (./conftest; exit) 2>/dev/null; then
@@ -922,12 +942,12 @@
   { echo "configure: error: installation or configuration problem: C compiler cannot create executables." 1>&2; exit 1; }
 fi
 echo $ac_n "checking whether the C compiler ($CC $CFLAGS $LDFLAGS) is a cross-compiler""... $ac_c" 1>&6
-echo "configure:926: checking whether the C compiler ($CC $CFLAGS $LDFLAGS) is a cross-compiler" >&5
+echo "configure:946: checking whether the C compiler ($CC $CFLAGS $LDFLAGS) is a cross-compiler" >&5
 echo "$ac_t""$ac_cv_prog_cc_cross" 1>&6
 cross_compiling=$ac_cv_prog_cc_cross
 
 echo $ac_n "checking whether we are using GNU C""... $ac_c" 1>&6
-echo "configure:931: checking whether we are using GNU C" >&5
+echo "configure:951: checking whether we are using GNU C" >&5
 if eval "test \"`echo '$''{'ac_cv_prog_gcc'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
@@ -936,7 +956,7 @@
   yes;
 #endif
 EOF
-if { ac_try='${CC-cc} -E conftest.c'; { (eval echo configure:940: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }; } | egrep yes >/dev/null 2>&1; then
+if { ac_try='${CC-cc} -E conftest.c'; { (eval echo configure:960: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }; } | egrep yes >/dev/null 2>&1; then
   ac_cv_prog_gcc=yes
 else
   ac_cv_prog_gcc=no
@@ -951,7 +971,7 @@
   ac_save_CFLAGS="$CFLAGS"
   CFLAGS=
   echo $ac_n "checking whether ${CC-cc} accepts -g""... $ac_c" 1>&6
-echo "configure:955: checking whether ${CC-cc} accepts -g" >&5
+echo "configure:975: checking whether ${CC-cc} accepts -g" >&5
 if eval "test \"`echo '$''{'ac_cv_prog_cc_g'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
@@ -1034,7 +1054,7 @@
 
 
 echo $ac_n "checking how to run the C preprocessor""... $ac_c" 1>&6
-echo "configure:1038: checking how to run the C preprocessor" >&5
+echo "configure:1058: checking how to run the C preprocessor" >&5
 # On Suns, sometimes $CPP names a directory.
 if test -n "$CPP" && test -d "$CPP"; then
   CPP=
@@ -1049,13 +1069,13 @@
   # On the NeXT, cc -E runs the code through the compiler's parser,
   # not just through cpp.
   cat > conftest.$ac_ext <<EOF
-#line 1053 "configure"
+#line 1073 "configure"
 #include "confdefs.h"
 #include <assert.h>
 Syntax Error
 EOF
 ac_try="$ac_cpp conftest.$ac_ext >/dev/null 2>conftest.out"
-{ (eval echo configure:1059: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }
+{ (eval echo configure:1079: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }
 ac_err=`grep -v '^ *+' conftest.out`
 if test -z "$ac_err"; then
   :
@@ -1066,13 +1086,13 @@
   rm -rf conftest*
   CPP="${CC-cc} -E -traditional-cpp"
   cat > conftest.$ac_ext <<EOF
-#line 1070 "configure"
+#line 1090 "configure"
 #include "confdefs.h"
 #include <assert.h>
 Syntax Error
 EOF
 ac_try="$ac_cpp conftest.$ac_ext >/dev/null 2>conftest.out"
-{ (eval echo configure:1076: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }
+{ (eval echo configure:1096: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }
 ac_err=`grep -v '^ *+' conftest.out`
 if test -z "$ac_err"; then
   :
@@ -1095,13 +1115,13 @@
 echo "$ac_t""$CPP" 1>&6
                  if test $ac_cv_prog_gcc = yes; then
     echo $ac_n "checking whether ${CC-cc} needs -traditional""... $ac_c" 1>&6
-echo "configure:1099: checking whether ${CC-cc} needs -traditional" >&5
+echo "configure:1119: checking whether ${CC-cc} needs -traditional" >&5
 if eval "test \"`echo '$''{'ac_cv_prog_gcc_traditional'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
     ac_pattern="Autoconf.*'x'"
   cat > conftest.$ac_ext <<EOF
-#line 1105 "configure"
+#line 1125 "configure"
 #include "confdefs.h"
 #include <sgtty.h>
 Autoconf TIOCGETP
@@ -1119,7 +1139,7 @@
 
   if test $ac_cv_prog_gcc_traditional = no; then
     cat > conftest.$ac_ext <<EOF
-#line 1123 "configure"
+#line 1143 "configure"
 #include "confdefs.h"
 #include <termio.h>
 Autoconf TCGETA
@@ -1140,12 +1160,12 @@
   fi
 fi
      echo $ac_n "checking for working const""... $ac_c" 1>&6
-echo "configure:1144: checking for working const" >&5
+echo "configure:1164: checking for working const" >&5
 if eval "test \"`echo '$''{'ac_cv_c_const'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 1149 "configure"
+#line 1169 "configure"
 #include "confdefs.h"
 
 int main() {
@@ -1194,7 +1214,7 @@
 
 ; return 0; }
 EOF
-if { (eval echo configure:1198: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
+if { (eval echo configure:1218: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
   rm -rf conftest*
   ac_cv_c_const=yes
 else
@@ -1215,7 +1235,7 @@
 fi
                   
 echo $ac_n "checking for ${CC-cc} option to accept ANSI C""... $ac_c" 1>&6
-echo "configure:1219: checking for ${CC-cc} option to accept ANSI C" >&5
+echo "configure:1239: checking for ${CC-cc} option to accept ANSI C" >&5
 if eval "test \"`echo '$''{'fp_cv_prog_cc_stdc'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
@@ -1231,7 +1251,7 @@
 do
   CFLAGS="$ac_save_CFLAGS $ac_arg"
   cat > conftest.$ac_ext <<EOF
-#line 1235 "configure"
+#line 1255 "configure"
 #include "confdefs.h"
 #ifndef __STDC__
 choke me
@@ -1243,7 +1263,7 @@
 struct s2 {int (*f) (double a);};
 ; return 0; }
 EOF
-if { (eval echo configure:1247: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
+if { (eval echo configure:1267: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
   rm -rf conftest*
   fp_cv_prog_cc_stdc="$ac_arg"; break
 else
@@ -1263,7 +1283,7 @@
 esac
 
 echo $ac_n "checking whether to use prototypes""... $ac_c" 1>&6
-echo "configure:1267: checking whether to use prototypes" >&5
+echo "configure:1287: checking whether to use prototypes" >&5
 if test ."$ansi2knr" = .yes || test ."$ansi2knr" = .no; then
   msg="(overridden) "
 else
@@ -1290,19 +1310,19 @@
 # The Ultrix 4.2 mips builtin alloca declared by alloca.h only works
 # for constant arguments.  Useless!
 echo $ac_n "checking for working alloca.h""... $ac_c" 1>&6
-echo "configure:1294: checking for working alloca.h" >&5
+echo "configure:1314: checking for working alloca.h" >&5
 if eval "test \"`echo '$''{'ac_cv_header_alloca_h'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 1299 "configure"
+#line 1319 "configure"
 #include "confdefs.h"
 #include <alloca.h>
 int main() {
 char *p = alloca(2 * sizeof(int));
 ; return 0; }
 EOF
-if { (eval echo configure:1306: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
+if { (eval echo configure:1326: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
   rm -rf conftest*
   ac_cv_header_alloca_h=yes
 else
@@ -1323,12 +1343,12 @@
 fi
 
 echo $ac_n "checking for alloca""... $ac_c" 1>&6
-echo "configure:1327: checking for alloca" >&5
+echo "configure:1347: checking for alloca" >&5
 if eval "test \"`echo '$''{'ac_cv_func_alloca_works'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 1332 "configure"
+#line 1352 "configure"
 #include "confdefs.h"
 
 #ifdef __GNUC__
@@ -1351,7 +1371,7 @@
 char *p = (char *) alloca(1);
 ; return 0; }
 EOF
-if { (eval echo configure:1355: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
+if { (eval echo configure:1375: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
   rm -rf conftest*
   ac_cv_func_alloca_works=yes
 else
@@ -1383,12 +1403,12 @@
 
 
 echo $ac_n "checking whether alloca needs Cray hooks""... $ac_c" 1>&6
-echo "configure:1387: checking whether alloca needs Cray hooks" >&5
+echo "configure:1407: checking whether alloca needs Cray hooks" >&5
 if eval "test \"`echo '$''{'ac_cv_os_cray'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 1392 "configure"
+#line 1412 "configure"
 #include "confdefs.h"
 #if defined(CRAY) && ! defined(CRAY2)
 webecray
@@ -1413,12 +1433,12 @@
 if test $ac_cv_os_cray = yes; then
 for ac_func in _getb67 GETB67 getb67; do
   echo $ac_n "checking for $ac_func""... $ac_c" 1>&6
-echo "configure:1417: checking for $ac_func" >&5
+echo "configure:1437: checking for $ac_func" >&5
 if eval "test \"`echo '$''{'ac_cv_func_$ac_func'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 1422 "configure"
+#line 1442 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func(); below.  */
@@ -1441,7 +1461,7 @@
 
 ; return 0; }
 EOF
-if { (eval echo configure:1445: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
+if { (eval echo configure:1465: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
   rm -rf conftest*
   eval "ac_cv_func_$ac_func=yes"
 else
@@ -1468,7 +1488,7 @@
 fi
 
 echo $ac_n "checking stack direction for C alloca""... $ac_c" 1>&6
-echo "configure:1472: checking stack direction for C alloca" >&5
+echo "configure:1492: checking stack direction for C alloca" >&5
 if eval "test \"`echo '$''{'ac_cv_c_stack_direction'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
@@ -1476,7 +1496,7 @@
   ac_cv_c_stack_direction=0
 else
   cat > conftest.$ac_ext <<EOF
-#line 1480 "configure"
+#line 1500 "configure"
 #include "confdefs.h"
 find_stack_direction ()
 {
@@ -1495,7 +1515,7 @@
   exit (find_stack_direction() < 0);
 }
 EOF
-if { (eval echo configure:1499: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
+if { (eval echo configure:1519: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
 then
   ac_cv_c_stack_direction=1
 else
@@ -1517,19 +1537,19 @@
 fi
               
 echo $ac_n "checking if the compiler supports union initialisation""... $ac_c" 1>&6
-echo "configure:1521: checking if the compiler supports union initialisation" >&5
+echo "configure:1541: checking if the compiler supports union initialisation" >&5
 if eval "test \"`echo '$''{'zsh_cv_c_have_union_init'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 1526 "configure"
+#line 1546 "configure"
 #include "confdefs.h"
 union{void *p;long l;}u={0};
 int main() {
 u.l=1;
 ; return 0; }
 EOF
-if { (eval echo configure:1533: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
+if { (eval echo configure:1553: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
   rm -rf conftest*
   zsh_cv_c_have_union_init=yes
 else
@@ -1550,7 +1570,7 @@
 fi
 
 echo $ac_n "checking if signed to unsigned casting is broken""... $ac_c" 1>&6
-echo "configure:1554: checking if signed to unsigned casting is broken" >&5
+echo "configure:1574: checking if signed to unsigned casting is broken" >&5
 if eval "test \"`echo '$''{'zsh_cv_c_broken_signed_to_unsigned_casting'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
@@ -1558,11 +1578,11 @@
   zsh_cv_c_broken_signed_to_unsigned_casting=no
 else
   cat > conftest.$ac_ext <<EOF
-#line 1562 "configure"
+#line 1582 "configure"
 #include "confdefs.h"
 main(){return((int)(unsigned char)((char) -1) == 255);}
 EOF
-if { (eval echo configure:1566: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
+if { (eval echo configure:1586: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
 then
   zsh_cv_c_broken_signed_to_unsigned_casting=yes
 else
@@ -1585,19 +1605,19 @@
 fi
 
 echo $ac_n "checking if the compiler supports variable-lenth arrays""... $ac_c" 1>&6
-echo "configure:1589: checking if the compiler supports variable-lenth arrays" >&5
+echo "configure:1609: checking if the compiler supports variable-lenth arrays" >&5
 if eval "test \"`echo '$''{'zsh_cv_c_variable_length_arrays'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 1594 "configure"
+#line 1614 "configure"
 #include "confdefs.h"
 int foo();
 int main() {
 int i[foo()];
 ; return 0; }
 EOF
-if { (eval echo configure:1601: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
+if { (eval echo configure:1621: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
   rm -rf conftest*
   zsh_cv_c_variable_length_arrays=yes
 else
@@ -1618,7 +1638,7 @@
 fi
 
 echo $ac_n "checking whether ${MAKE-make} sets \${MAKE}""... $ac_c" 1>&6
-echo "configure:1622: checking whether ${MAKE-make} sets \${MAKE}" >&5
+echo "configure:1642: checking whether ${MAKE-make} sets \${MAKE}" >&5
 set dummy ${MAKE-make}; ac_make=`echo "$2" | sed 'y%./+-%__p_%'`
 if eval "test \"`echo '$''{'ac_cv_prog_make_${ac_make}_set'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
@@ -1654,7 +1674,7 @@
 # SVR4 /usr/ucb/install, which tries to use the nonexistent group "staff"
 # ./install, which can be erroneously created by make from ./install.sh.
 echo $ac_n "checking for a BSD compatible install""... $ac_c" 1>&6
-echo "configure:1658: checking for a BSD compatible install" >&5
+echo "configure:1678: checking for a BSD compatible install" >&5
 if test -z "$INSTALL"; then
 if eval "test \"`echo '$''{'ac_cv_path_install'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
@@ -1707,7 +1727,7 @@
 # Extract the first word of "$ac_prog", so it can be a program name with args.
 set dummy $ac_prog; ac_word=$2
 echo $ac_n "checking for $ac_word""... $ac_c" 1>&6
-echo "configure:1711: checking for $ac_word" >&5
+echo "configure:1731: checking for $ac_word" >&5
 if eval "test \"`echo '$''{'ac_cv_prog_AWK'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
@@ -1739,7 +1759,7 @@
 # Extract the first word of "$ac_prog", so it can be a program name with args.
 set dummy $ac_prog; ac_word=$2
 echo $ac_n "checking for $ac_word""... $ac_c" 1>&6
-echo "configure:1743: checking for $ac_word" >&5
+echo "configure:1763: checking for $ac_word" >&5
 if eval "test \"`echo '$''{'ac_cv_prog_YODL'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
@@ -1774,12 +1794,12 @@
 do
 ac_safe=`echo "$ac_hdr" | sed 'y%./+-%__p_%'`
 echo $ac_n "checking for $ac_hdr that defines DIR""... $ac_c" 1>&6
-echo "configure:1778: checking for $ac_hdr that defines DIR" >&5
+echo "configure:1798: checking for $ac_hdr that defines DIR" >&5
 if eval "test \"`echo '$''{'ac_cv_header_dirent_$ac_safe'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 1783 "configure"
+#line 1803 "configure"
 #include "confdefs.h"
 #include <sys/types.h>
 #include <$ac_hdr>
@@ -1787,7 +1807,7 @@
 DIR *dirp = 0;
 ; return 0; }
 EOF
-if { (eval echo configure:1791: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
+if { (eval echo configure:1811: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
   rm -rf conftest*
   eval "ac_cv_header_dirent_$ac_safe=yes"
 else
@@ -1812,7 +1832,7 @@
 # Two versions of opendir et al. are in -ldir and -lx on SCO Xenix.
 if test $ac_header_dirent = dirent.h; then
 echo $ac_n "checking for opendir in -ldir""... $ac_c" 1>&6
-echo "configure:1816: checking for opendir in -ldir" >&5
+echo "configure:1836: checking for opendir in -ldir" >&5
 ac_lib_var=`echo dir'_'opendir | sed 'y%./+-%__p_%'`
 if eval "test \"`echo '$''{'ac_cv_lib_$ac_lib_var'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
@@ -1820,7 +1840,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-ldir  $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 1824 "configure"
+#line 1844 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 /* We use char because int might match the return type of a gcc2
@@ -1831,7 +1851,7 @@
 opendir()
 ; return 0; }
 EOF
-if { (eval echo configure:1835: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
+if { (eval echo configure:1855: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
   rm -rf conftest*
   eval "ac_cv_lib_$ac_lib_var=yes"
 else
@@ -1853,7 +1873,7 @@
 
 else
 echo $ac_n "checking for opendir in -lx""... $ac_c" 1>&6
-echo "configure:1857: checking for opendir in -lx" >&5
+echo "configure:1877: checking for opendir in -lx" >&5
 ac_lib_var=`echo x'_'opendir | sed 'y%./+-%__p_%'`
 if eval "test \"`echo '$''{'ac_cv_lib_$ac_lib_var'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
@@ -1861,7 +1881,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-lx  $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 1865 "configure"
+#line 1885 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 /* We use char because int might match the return type of a gcc2
@@ -1872,7 +1892,7 @@
 opendir()
 ; return 0; }
 EOF
-if { (eval echo configure:1876: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
+if { (eval echo configure:1896: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
   rm -rf conftest*
   eval "ac_cv_lib_$ac_lib_var=yes"
 else
@@ -1895,12 +1915,12 @@
 fi
 
 echo $ac_n "checking for ANSI C header files""... $ac_c" 1>&6
-echo "configure:1899: checking for ANSI C header files" >&5
+echo "configure:1919: checking for ANSI C header files" >&5
 if eval "test \"`echo '$''{'ac_cv_header_stdc'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 1904 "configure"
+#line 1924 "configure"
 #include "confdefs.h"
 #include <stdlib.h>
 #include <stdarg.h>
@@ -1908,7 +1928,7 @@
 #include <float.h>
 EOF
 ac_try="$ac_cpp conftest.$ac_ext >/dev/null 2>conftest.out"
-{ (eval echo configure:1912: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }
+{ (eval echo configure:1932: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }
 ac_err=`grep -v '^ *+' conftest.out`
 if test -z "$ac_err"; then
   rm -rf conftest*
@@ -1925,7 +1945,7 @@
 if test $ac_cv_header_stdc = yes; then
   # SunOS 4.x string.h does not declare mem*, contrary to ANSI.
 cat > conftest.$ac_ext <<EOF
-#line 1929 "configure"
+#line 1949 "configure"
 #include "confdefs.h"
 #include <string.h>
 EOF
@@ -1943,7 +1963,7 @@
 if test $ac_cv_header_stdc = yes; then
   # ISC 2.0.2 stdlib.h does not declare free, contrary to ANSI.
 cat > conftest.$ac_ext <<EOF
-#line 1947 "configure"
+#line 1967 "configure"
 #include "confdefs.h"
 #include <stdlib.h>
 EOF
@@ -1964,7 +1984,7 @@
   :
 else
   cat > conftest.$ac_ext <<EOF
-#line 1968 "configure"
+#line 1988 "configure"
 #include "confdefs.h"
 #include <ctype.h>
 #define ISLOWER(c) ('a' <= (c) && (c) <= 'z')
@@ -1975,7 +1995,7 @@
 exit (0); }
 
 EOF
-if { (eval echo configure:1979: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
+if { (eval echo configure:1999: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
 then
   :
 else
@@ -1999,12 +2019,12 @@
 fi
 
 echo $ac_n "checking whether time.h and sys/time.h may both be included""... $ac_c" 1>&6
-echo "configure:2003: checking whether time.h and sys/time.h may both be included" >&5
+echo "configure:2023: checking whether time.h and sys/time.h may both be included" >&5
 if eval "test \"`echo '$''{'ac_cv_header_time'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 2008 "configure"
+#line 2028 "configure"
 #include "confdefs.h"
 #include <sys/types.h>
 #include <sys/time.h>
@@ -2013,7 +2033,7 @@
 struct tm *tp;
 ; return 0; }
 EOF
-if { (eval echo configure:2017: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
+if { (eval echo configure:2037: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
   rm -rf conftest*
   ac_cv_header_time=yes
 else
@@ -2034,12 +2054,12 @@
 fi
 
 echo $ac_n "checking whether stat file-mode macros are broken""... $ac_c" 1>&6
-echo "configure:2038: checking whether stat file-mode macros are broken" >&5
+echo "configure:2058: checking whether stat file-mode macros are broken" >&5
 if eval "test \"`echo '$''{'ac_cv_header_stat_broken'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 2043 "configure"
+#line 2063 "configure"
 #include "confdefs.h"
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -2090,12 +2110,12 @@
 fi
 
 echo $ac_n "checking for sys/wait.h that is POSIX.1 compatible""... $ac_c" 1>&6
-echo "configure:2094: checking for sys/wait.h that is POSIX.1 compatible" >&5
+echo "configure:2114: checking for sys/wait.h that is POSIX.1 compatible" >&5
 if eval "test \"`echo '$''{'ac_cv_header_sys_wait_h'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 2099 "configure"
+#line 2119 "configure"
 #include "confdefs.h"
 #include <sys/types.h>
 #include <sys/wait.h>
@@ -2111,7 +2131,7 @@
 s = WIFEXITED (s) ? WEXITSTATUS (s) : 1;
 ; return 0; }
 EOF
-if { (eval echo configure:2115: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
+if { (eval echo configure:2135: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
   rm -rf conftest*
   ac_cv_header_sys_wait_h=yes
 else
@@ -2139,17 +2159,17 @@
 do
 ac_safe=`echo "$ac_hdr" | sed 'y%./+-%__p_%'`
 echo $ac_n "checking for $ac_hdr""... $ac_c" 1>&6
-echo "configure:2143: checking for $ac_hdr" >&5
+echo "configure:2163: checking for $ac_hdr" >&5
 if eval "test \"`echo '$''{'ac_cv_header_$ac_safe'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 2148 "configure"
+#line 2168 "configure"
 #include "confdefs.h"
 #include <$ac_hdr>
 EOF
 ac_try="$ac_cpp conftest.$ac_ext >/dev/null 2>conftest.out"
-{ (eval echo configure:2153: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }
+{ (eval echo configure:2173: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }
 ac_err=`grep -v '^ *+' conftest.out`
 if test -z "$ac_err"; then
   rm -rf conftest*
@@ -2180,17 +2200,17 @@
 do
 ac_safe=`echo "$ac_hdr" | sed 'y%./+-%__p_%'`
 echo $ac_n "checking for $ac_hdr""... $ac_c" 1>&6
-echo "configure:2184: checking for $ac_hdr" >&5
+echo "configure:2204: checking for $ac_hdr" >&5
 if eval "test \"`echo '$''{'ac_cv_header_$ac_safe'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 2189 "configure"
+#line 2209 "configure"
 #include "confdefs.h"
 #include <$ac_hdr>
 EOF
 ac_try="$ac_cpp conftest.$ac_ext >/dev/null 2>conftest.out"
-{ (eval echo configure:2194: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }
+{ (eval echo configure:2214: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }
 ac_err=`grep -v '^ *+' conftest.out`
 if test -z "$ac_err"; then
   rm -rf conftest*
@@ -2220,12 +2240,12 @@
 
 if test $ac_cv_header_sys_time_h = yes -a $ac_cv_header_sys_select_h = yes; then
   echo $ac_n "checking for conflicts in sys/time.h and sys/select.h""... $ac_c" 1>&6
-echo "configure:2224: checking for conflicts in sys/time.h and sys/select.h" >&5
+echo "configure:2244: checking for conflicts in sys/time.h and sys/select.h" >&5
 if eval "test \"`echo '$''{'zsh_cv_header_time_h_select_h_conflicts'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 2229 "configure"
+#line 2249 "configure"
 #include "confdefs.h"
 #include <sys/time.h>
 #include <sys/select.h>
@@ -2233,7 +2253,7 @@
 int i;
 ; return 0; }
 EOF
-if { (eval echo configure:2237: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
+if { (eval echo configure:2257: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
   rm -rf conftest*
   zsh_cv_header_time_h_select_h_conflicts=no
 else
@@ -2255,12 +2275,12 @@
 fi
 
 echo $ac_n "checking POSIX termios""... $ac_c" 1>&6
-echo "configure:2259: checking POSIX termios" >&5
+echo "configure:2279: checking POSIX termios" >&5
 if eval "test \"`echo '$''{'zsh_cv_sys_posix_termios'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 2264 "configure"
+#line 2284 "configure"
 #include "confdefs.h"
 #include <sys/types.h>
 #include <unistd.h>
@@ -2270,7 +2290,7 @@
 tcgetattr(0, 0);
 ; return 0; }
 EOF
-if { (eval echo configure:2274: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
+if { (eval echo configure:2294: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
   rm -rf conftest*
   zsh_cv_sys_posix_termios=yes
 else
@@ -2286,12 +2306,12 @@
 
 if test $zsh_cv_sys_posix_termios = yes; then
   echo $ac_n "checking TIOCGWINSZ in termios.h""... $ac_c" 1>&6
-echo "configure:2290: checking TIOCGWINSZ in termios.h" >&5
+echo "configure:2310: checking TIOCGWINSZ in termios.h" >&5
 if eval "test \"`echo '$''{'zsh_cv_header_termios_h_tiocgwinsz'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 2295 "configure"
+#line 2315 "configure"
 #include "confdefs.h"
 #include <sys/types.h>
 #include <termios.h>
@@ -2299,7 +2319,7 @@
 int x = TIOCGWINSZ;
 ; return 0; }
 EOF
-if { (eval echo configure:2303: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
+if { (eval echo configure:2323: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
   rm -rf conftest*
   zsh_cv_header_termios_h_tiocgwinsz=yes
 else
@@ -2318,12 +2338,12 @@
  
 if test $zsh_cv_header_termios_h_tiocgwinsz = no; then
   echo $ac_n "checking TIOCGWINSZ in sys/ioctl.h""... $ac_c" 1>&6
-echo "configure:2322: checking TIOCGWINSZ in sys/ioctl.h" >&5
+echo "configure:2342: checking TIOCGWINSZ in sys/ioctl.h" >&5
 if eval "test \"`echo '$''{'zsh_cv_header_sys_ioctl_h_tiocgwinsz'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 2327 "configure"
+#line 2347 "configure"
 #include "confdefs.h"
 #include <sys/types.h>
 #include <sys/ioctl.h>
@@ -2331,7 +2351,7 @@
 int x = TIOCGWINSZ;
 ; return 0; }
 EOF
-if { (eval echo configure:2335: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
+if { (eval echo configure:2355: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
   rm -rf conftest*
   zsh_cv_header_sys_ioctl_h_tiocgwinsz=yes
 else
@@ -2354,17 +2374,17 @@
  
 ac_safe=`echo "sys/ptem.h" | sed 'y%./+-%__p_%'`
 echo $ac_n "checking for sys/ptem.h""... $ac_c" 1>&6
-echo "configure:2358: checking for sys/ptem.h" >&5
+echo "configure:2378: checking for sys/ptem.h" >&5
 if eval "test \"`echo '$''{'ac_cv_header_$ac_safe'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 2363 "configure"
+#line 2383 "configure"
 #include "confdefs.h"
 #include <sys/ptem.h>
 EOF
 ac_try="$ac_cpp conftest.$ac_ext >/dev/null 2>conftest.out"
-{ (eval echo configure:2368: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }
+{ (eval echo configure:2388: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }
 ac_err=`grep -v '^ *+' conftest.out`
 if test -z "$ac_err"; then
   rm -rf conftest*
@@ -2391,7 +2411,7 @@
 
 
 echo $ac_n "checking for printf in -lc""... $ac_c" 1>&6
-echo "configure:2395: checking for printf in -lc" >&5
+echo "configure:2415: checking for printf in -lc" >&5
 ac_lib_var=`echo c'_'printf | sed 'y%./+-%__p_%'`
 if eval "test \"`echo '$''{'ac_cv_lib_$ac_lib_var'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
@@ -2399,7 +2419,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-lc  $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 2403 "configure"
+#line 2423 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 /* We use char because int might match the return type of a gcc2
@@ -2410,7 +2430,7 @@
 printf()
 ; return 0; }
 EOF
-if { (eval echo configure:2414: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
+if { (eval echo configure:2434: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
   rm -rf conftest*
   eval "ac_cv_lib_$ac_lib_var=yes"
 else
@@ -2447,7 +2467,7 @@
 
 for lib in $termcap_curses_order; do
   echo $ac_n "checking for tgetent in -l${lib}""... $ac_c" 1>&6
-echo "configure:2451: checking for tgetent in -l${lib}" >&5
+echo "configure:2471: checking for tgetent in -l${lib}" >&5
 ac_lib_var=`echo ${lib}'_'tgetent | sed 'y%./+-%__p_%'`
 if eval "test \"`echo '$''{'ac_cv_lib_$ac_lib_var'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
@@ -2455,7 +2475,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-l${lib}  $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 2459 "configure"
+#line 2479 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 /* We use char because int might match the return type of a gcc2
@@ -2466,7 +2486,7 @@
 tgetent()
 ; return 0; }
 EOF
-if { (eval echo configure:2470: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
+if { (eval echo configure:2490: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
   rm -rf conftest*
   eval "ac_cv_lib_$ac_lib_var=yes"
 else
@@ -2491,12 +2511,12 @@
 for ac_func in yp_all
 do
 echo $ac_n "checking for $ac_func""... $ac_c" 1>&6
-echo "configure:2495: checking for $ac_func" >&5
+echo "configure:2515: checking for $ac_func" >&5
 if eval "test \"`echo '$''{'ac_cv_func_$ac_func'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 2500 "configure"
+#line 2520 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func(); below.  */
@@ -2519,7 +2539,7 @@
 
 ; return 0; }
 EOF
-if { (eval echo configure:2523: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
+if { (eval echo configure:2543: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
   rm -rf conftest*
   eval "ac_cv_func_$ac_func=yes"
 else
@@ -2545,7 +2565,7 @@
 
 if test $ac_cv_func_yp_all = no; then
   echo $ac_n "checking for yp_all in -lnsl""... $ac_c" 1>&6
-echo "configure:2549: checking for yp_all in -lnsl" >&5
+echo "configure:2569: checking for yp_all in -lnsl" >&5
 ac_lib_var=`echo nsl'_'yp_all | sed 'y%./+-%__p_%'`
 if eval "test \"`echo '$''{'ac_cv_lib_$ac_lib_var'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
@@ -2553,7 +2573,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-lnsl  $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 2557 "configure"
+#line 2577 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 /* We use char because int might match the return type of a gcc2
@@ -2564,7 +2584,7 @@
 yp_all()
 ; return 0; }
 EOF
-if { (eval echo configure:2568: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
+if { (eval echo configure:2588: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
   rm -rf conftest*
   eval "ac_cv_lib_$ac_lib_var=yes"
 else
@@ -2599,7 +2619,7 @@
 
 if test "x$dynamic" = xyes; then
   echo $ac_n "checking for dlopen in -ldl""... $ac_c" 1>&6
-echo "configure:2603: checking for dlopen in -ldl" >&5
+echo "configure:2623: checking for dlopen in -ldl" >&5
 ac_lib_var=`echo dl'_'dlopen | sed 'y%./+-%__p_%'`
 if eval "test \"`echo '$''{'ac_cv_lib_$ac_lib_var'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
@@ -2607,7 +2627,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-ldl  $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 2611 "configure"
+#line 2631 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 /* We use char because int might match the return type of a gcc2
@@ -2618,7 +2638,7 @@
 dlopen()
 ; return 0; }
 EOF
-if { (eval echo configure:2622: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
+if { (eval echo configure:2642: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
   rm -rf conftest*
   eval "ac_cv_lib_$ac_lib_var=yes"
 else
@@ -2648,7 +2668,7 @@
 fi
 
 echo $ac_n "checking for cap_get_proc in -lcap""... $ac_c" 1>&6
-echo "configure:2652: checking for cap_get_proc in -lcap" >&5
+echo "configure:2672: checking for cap_get_proc in -lcap" >&5
 ac_lib_var=`echo cap'_'cap_get_proc | sed 'y%./+-%__p_%'`
 if eval "test \"`echo '$''{'ac_cv_lib_$ac_lib_var'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
@@ -2656,7 +2676,7 @@
   ac_save_LIBS="$LIBS"
 LIBS="-lcap  $LIBS"
 cat > conftest.$ac_ext <<EOF
-#line 2660 "configure"
+#line 2680 "configure"
 #include "confdefs.h"
 /* Override any gcc2 internal prototype to avoid an error.  */
 /* We use char because int might match the return type of a gcc2
@@ -2667,7 +2687,7 @@
 cap_get_proc()
 ; return 0; }
 EOF
-if { (eval echo configure:2671: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
+if { (eval echo configure:2691: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
   rm -rf conftest*
   eval "ac_cv_lib_$ac_lib_var=yes"
 else
@@ -2696,12 +2716,12 @@
 
 
 echo $ac_n "checking if an include file defines ospeed""... $ac_c" 1>&6
-echo "configure:2700: checking if an include file defines ospeed" >&5
+echo "configure:2720: checking if an include file defines ospeed" >&5
 if eval "test \"`echo '$''{'zsh_cv_decl_ospeed_include_defines'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 2705 "configure"
+#line 2725 "configure"
 #include "confdefs.h"
 #include <sys/types.h>
 #if HAVE_TERMIOS_H
@@ -2714,7 +2734,7 @@
 ospeed = 0;
 ; return 0; }
 EOF
-if { (eval echo configure:2718: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
+if { (eval echo configure:2738: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
   rm -rf conftest*
   zsh_cv_decl_ospeed_include_defines=yes
 else
@@ -2730,19 +2750,19 @@
 
 if test $zsh_cv_decl_ospeed_include_defines = no; then
   echo $ac_n "checking if you must define ospeed""... $ac_c" 1>&6
-echo "configure:2734: checking if you must define ospeed" >&5
+echo "configure:2754: checking if you must define ospeed" >&5
 if eval "test \"`echo '$''{'zsh_cv_decl_ospeed_must_define'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 2739 "configure"
+#line 2759 "configure"
 #include "confdefs.h"
 
 int main() {
 extern short ospeed; ospeed = 0;
 ; return 0; }
 EOF
-if { (eval echo configure:2746: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
+if { (eval echo configure:2766: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
   rm -rf conftest*
   zsh_cv_decl_ospeed_must_define=yes
 else
@@ -2774,7 +2794,7 @@
 fi
 
 echo $ac_n "checking if tgetent accepts NULL""... $ac_c" 1>&6
-echo "configure:2778: checking if tgetent accepts NULL" >&5
+echo "configure:2798: checking if tgetent accepts NULL" >&5
 if eval "test \"`echo '$''{'zsh_cv_func_tgetent_accepts_null'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
@@ -2782,11 +2802,11 @@
   zsh_cv_func_tgetent_accepts_null=no
 else
   cat > conftest.$ac_ext <<EOF
-#line 2786 "configure"
+#line 2806 "configure"
 #include "confdefs.h"
 main(){int i = tgetent((char*)0,"vt100");exit(!i || i == -1);}
 EOF
-if { (eval echo configure:2790: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
+if { (eval echo configure:2810: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
 then
   zsh_cv_func_tgetent_accepts_null=yes
 else
@@ -2810,12 +2830,12 @@
 
 
 echo $ac_n "checking return type of signal handlers""... $ac_c" 1>&6
-echo "configure:2814: checking return type of signal handlers" >&5
+echo "configure:2834: checking return type of signal handlers" >&5
 if eval "test \"`echo '$''{'ac_cv_type_signal'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 2819 "configure"
+#line 2839 "configure"
 #include "confdefs.h"
 #include <sys/types.h>
 #include <signal.h>
@@ -2832,7 +2852,7 @@
 int i;
 ; return 0; }
 EOF
-if { (eval echo configure:2836: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
+if { (eval echo configure:2856: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
   rm -rf conftest*
   ac_cv_type_signal=void
 else
@@ -2851,12 +2871,12 @@
 
 
 echo $ac_n "checking for pid_t""... $ac_c" 1>&6
-echo "configure:2855: checking for pid_t" >&5
+echo "configure:2875: checking for pid_t" >&5
 if eval "test \"`echo '$''{'ac_cv_type_pid_t'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 2860 "configure"
+#line 2880 "configure"
 #include "confdefs.h"
 #include <sys/types.h>
 #if STDC_HEADERS
@@ -2884,12 +2904,12 @@
 fi
 
 echo $ac_n "checking for off_t""... $ac_c" 1>&6
-echo "configure:2888: checking for off_t" >&5
+echo "configure:2908: checking for off_t" >&5
 if eval "test \"`echo '$''{'ac_cv_type_off_t'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 2893 "configure"
+#line 2913 "configure"
 #include "confdefs.h"
 #include <sys/types.h>
 #if STDC_HEADERS
@@ -2917,12 +2937,12 @@
 fi
 
 echo $ac_n "checking for mode_t""... $ac_c" 1>&6
-echo "configure:2921: checking for mode_t" >&5
+echo "configure:2941: checking for mode_t" >&5
 if eval "test \"`echo '$''{'ac_cv_type_mode_t'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 2926 "configure"
+#line 2946 "configure"
 #include "confdefs.h"
 #include <sys/types.h>
 #if STDC_HEADERS
@@ -2950,12 +2970,12 @@
 fi
 
 echo $ac_n "checking for uid_t in sys/types.h""... $ac_c" 1>&6
-echo "configure:2954: checking for uid_t in sys/types.h" >&5
+echo "configure:2974: checking for uid_t in sys/types.h" >&5
 if eval "test \"`echo '$''{'ac_cv_type_uid_t'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 2959 "configure"
+#line 2979 "configure"
 #include "confdefs.h"
 #include <sys/types.h>
 EOF
@@ -2984,12 +3004,12 @@
 fi
 
 echo $ac_n "checking for size_t""... $ac_c" 1>&6
-echo "configure:2988: checking for size_t" >&5
+echo "configure:3008: checking for size_t" >&5
 if eval "test \"`echo '$''{'ac_cv_type_size_t'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 2993 "configure"
+#line 3013 "configure"
 #include "confdefs.h"
 #include <sys/types.h>
 #if STDC_HEADERS
@@ -3018,12 +3038,12 @@
 
 
 echo $ac_n "checking for sigset_t""... $ac_c" 1>&6
-echo "configure:3022: checking for sigset_t" >&5
+echo "configure:3042: checking for sigset_t" >&5
 if eval "test \"`echo '$''{'zsh_cv_type_sigset_t'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 3027 "configure"
+#line 3047 "configure"
 #include "confdefs.h"
 #include <sys/types.h>
 #include <signal.h>
@@ -3031,7 +3051,7 @@
 sigset_t tempsigset;
 ; return 0; }
 EOF
-if { (eval echo configure:3035: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
+if { (eval echo configure:3055: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
   rm -rf conftest*
   zsh_cv_type_sigset_t=yes
 else
@@ -3052,12 +3072,12 @@
 fi
 
 echo $ac_n "checking for struct timezone""... $ac_c" 1>&6
-echo "configure:3056: checking for struct timezone" >&5
+echo "configure:3076: checking for struct timezone" >&5
 if eval "test \"`echo '$''{'zsh_cv_type_exists_struct_timezone'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 3061 "configure"
+#line 3081 "configure"
 #include "confdefs.h"
 
 #ifdef HAVE_SYS_TIME_H
@@ -3068,7 +3088,7 @@
 struct timezone testvar;
 ; return 0; }
 EOF
-if { (eval echo configure:3072: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
+if { (eval echo configure:3092: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
   rm -rf conftest*
   zsh_cv_type_exists_struct_timezone=yes
 else
@@ -3091,12 +3111,12 @@
 
 
 echo $ac_n "checking for struct utmp""... $ac_c" 1>&6
-echo "configure:3095: checking for struct utmp" >&5
+echo "configure:3115: checking for struct utmp" >&5
 if eval "test \"`echo '$''{'zsh_cv_type_exists_struct_utmp'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 3100 "configure"
+#line 3120 "configure"
 #include "confdefs.h"
 
 #ifdef HAVE_SYS_TYPES_H
@@ -3110,7 +3130,7 @@
 struct utmp testvar;
 ; return 0; }
 EOF
-if { (eval echo configure:3114: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
+if { (eval echo configure:3134: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
   rm -rf conftest*
   zsh_cv_type_exists_struct_utmp=yes
 else
@@ -3132,12 +3152,12 @@
 fi
 
 echo $ac_n "checking for struct utmpx""... $ac_c" 1>&6
-echo "configure:3136: checking for struct utmpx" >&5
+echo "configure:3156: checking for struct utmpx" >&5
 if eval "test \"`echo '$''{'zsh_cv_type_exists_struct_utmpx'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 3141 "configure"
+#line 3161 "configure"
 #include "confdefs.h"
 
 #ifdef HAVE_SYS_TYPES_H
@@ -3151,7 +3171,7 @@
 struct utmpx testvar;
 ; return 0; }
 EOF
-if { (eval echo configure:3155: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
+if { (eval echo configure:3175: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
   rm -rf conftest*
   zsh_cv_type_exists_struct_utmpx=yes
 else
@@ -3174,12 +3194,12 @@
 
 
 echo $ac_n "checking for ut_host in struct utmp""... $ac_c" 1>&6
-echo "configure:3178: checking for ut_host in struct utmp" >&5
+echo "configure:3198: checking for ut_host in struct utmp" >&5
 if eval "test \"`echo '$''{'zsh_cv_struct_member_struct_utmp_ut_host'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 3183 "configure"
+#line 3203 "configure"
 #include "confdefs.h"
 
 #ifdef HAVE_SYS_TYPES_H
@@ -3193,7 +3213,7 @@
 struct utmp testvar; testvar.ut_host;
 ; return 0; }
 EOF
-if { (eval echo configure:3197: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
+if { (eval echo configure:3217: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
   rm -rf conftest*
   zsh_cv_struct_member_struct_utmp_ut_host=yes
 else
@@ -3215,12 +3235,12 @@
 fi
 
 echo $ac_n "checking for ut_host in struct utmpx""... $ac_c" 1>&6
-echo "configure:3219: checking for ut_host in struct utmpx" >&5
+echo "configure:3239: checking for ut_host in struct utmpx" >&5
 if eval "test \"`echo '$''{'zsh_cv_struct_member_struct_utmpx_ut_host'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 3224 "configure"
+#line 3244 "configure"
 #include "confdefs.h"
 
 #ifdef HAVE_SYS_TYPES_H
@@ -3234,7 +3254,7 @@
 struct utmpx testvar; testvar.ut_host;
 ; return 0; }
 EOF
-if { (eval echo configure:3238: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
+if { (eval echo configure:3258: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
   rm -rf conftest*
   zsh_cv_struct_member_struct_utmpx_ut_host=yes
 else
@@ -3256,12 +3276,12 @@
 fi
 
 echo $ac_n "checking for ut_xtime in struct utmpx""... $ac_c" 1>&6
-echo "configure:3260: checking for ut_xtime in struct utmpx" >&5
+echo "configure:3280: checking for ut_xtime in struct utmpx" >&5
 if eval "test \"`echo '$''{'zsh_cv_struct_member_struct_utmpx_ut_xtime'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 3265 "configure"
+#line 3285 "configure"
 #include "confdefs.h"
 
 #ifdef HAVE_SYS_TYPES_H
@@ -3275,7 +3295,7 @@
 struct utmpx testvar; testvar.ut_xtime;
 ; return 0; }
 EOF
-if { (eval echo configure:3279: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
+if { (eval echo configure:3299: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
   rm -rf conftest*
   zsh_cv_struct_member_struct_utmpx_ut_xtime=yes
 else
@@ -3297,12 +3317,12 @@
 fi
 
 echo $ac_n "checking for ut_tv in struct utmpx""... $ac_c" 1>&6
-echo "configure:3301: checking for ut_tv in struct utmpx" >&5
+echo "configure:3321: checking for ut_tv in struct utmpx" >&5
 if eval "test \"`echo '$''{'zsh_cv_struct_member_struct_utmpx_ut_tv'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 3306 "configure"
+#line 3326 "configure"
 #include "confdefs.h"
 
 #ifdef HAVE_SYS_TYPES_H
@@ -3316,7 +3336,7 @@
 struct utmpx testvar; testvar.ut_tv;
 ; return 0; }
 EOF
-if { (eval echo configure:3320: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
+if { (eval echo configure:3340: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
   rm -rf conftest*
   zsh_cv_struct_member_struct_utmpx_ut_tv=yes
 else
@@ -3339,12 +3359,12 @@
 
 
 echo $ac_n "checking for d_ino in struct dirent""... $ac_c" 1>&6
-echo "configure:3343: checking for d_ino in struct dirent" >&5
+echo "configure:3363: checking for d_ino in struct dirent" >&5
 if eval "test \"`echo '$''{'zsh_cv_struct_member_struct_dirent_d_ino'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 3348 "configure"
+#line 3368 "configure"
 #include "confdefs.h"
 
 #ifdef HAVE_SYS_TYPES_H
@@ -3358,7 +3378,7 @@
 struct dirent testvar; testvar.d_ino;
 ; return 0; }
 EOF
-if { (eval echo configure:3362: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
+if { (eval echo configure:3382: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
   rm -rf conftest*
   zsh_cv_struct_member_struct_dirent_d_ino=yes
 else
@@ -3380,12 +3400,12 @@
 fi
 
 echo $ac_n "checking for d_stat in struct dirent""... $ac_c" 1>&6
-echo "configure:3384: checking for d_stat in struct dirent" >&5
+echo "configure:3404: checking for d_stat in struct dirent" >&5
 if eval "test \"`echo '$''{'zsh_cv_struct_member_struct_dirent_d_stat'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 3389 "configure"
+#line 3409 "configure"
 #include "confdefs.h"
 
 #ifdef HAVE_SYS_TYPES_H
@@ -3399,7 +3419,7 @@
 struct dirent testvar; testvar.d_stat;
 ; return 0; }
 EOF
-if { (eval echo configure:3403: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
+if { (eval echo configure:3423: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
   rm -rf conftest*
   zsh_cv_struct_member_struct_dirent_d_stat=yes
 else
@@ -3421,12 +3441,12 @@
 fi
 
 echo $ac_n "checking for d_ino in struct direct""... $ac_c" 1>&6
-echo "configure:3425: checking for d_ino in struct direct" >&5
+echo "configure:3445: checking for d_ino in struct direct" >&5
 if eval "test \"`echo '$''{'zsh_cv_struct_member_struct_direct_d_ino'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 3430 "configure"
+#line 3450 "configure"
 #include "confdefs.h"
 
 #ifdef HAVE_SYS_TYPES_H
@@ -3446,7 +3466,7 @@
 struct direct testvar; testvar.d_ino;
 ; return 0; }
 EOF
-if { (eval echo configure:3450: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
+if { (eval echo configure:3470: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
   rm -rf conftest*
   zsh_cv_struct_member_struct_direct_d_ino=yes
 else
@@ -3468,12 +3488,12 @@
 fi
 
 echo $ac_n "checking for d_stat in struct direct""... $ac_c" 1>&6
-echo "configure:3472: checking for d_stat in struct direct" >&5
+echo "configure:3492: checking for d_stat in struct direct" >&5
 if eval "test \"`echo '$''{'zsh_cv_struct_member_struct_direct_d_stat'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 3477 "configure"
+#line 3497 "configure"
 #include "confdefs.h"
 
 #ifdef HAVE_SYS_TYPES_H
@@ -3493,7 +3513,7 @@
 struct direct testvar; testvar.d_stat;
 ; return 0; }
 EOF
-if { (eval echo configure:3497: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
+if { (eval echo configure:3517: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
   rm -rf conftest*
   zsh_cv_struct_member_struct_direct_d_stat=yes
 else
@@ -3516,7 +3536,7 @@
 
 
 echo $ac_n "checking whether getpgrp takes no argument""... $ac_c" 1>&6
-echo "configure:3520: checking whether getpgrp takes no argument" >&5
+echo "configure:3540: checking whether getpgrp takes no argument" >&5
 if eval "test \"`echo '$''{'ac_cv_func_getpgrp_void'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
@@ -3524,7 +3544,7 @@
   { echo "configure: error: cannot check getpgrp if cross compiling" 1>&2; exit 1; }
 else
   cat > conftest.$ac_ext <<EOF
-#line 3528 "configure"
+#line 3548 "configure"
 #include "confdefs.h"
 
 /*
@@ -3579,7 +3599,7 @@
 }
 
 EOF
-if { (eval echo configure:3583: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
+if { (eval echo configure:3603: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
 then
   ac_cv_func_getpgrp_void=yes
 else
@@ -3603,7 +3623,7 @@
 fi
 
 echo $ac_n "checking for working strcoll""... $ac_c" 1>&6
-echo "configure:3607: checking for working strcoll" >&5
+echo "configure:3627: checking for working strcoll" >&5
 if eval "test \"`echo '$''{'ac_cv_func_strcoll_works'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
@@ -3611,7 +3631,7 @@
   ac_cv_func_strcoll_works=no
 else
   cat > conftest.$ac_ext <<EOF
-#line 3615 "configure"
+#line 3635 "configure"
 #include "confdefs.h"
 #include <string.h>
 main ()
@@ -3621,7 +3641,7 @@
 	strcoll ("123", "456") >= 0);
 }
 EOF
-if { (eval echo configure:3625: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
+if { (eval echo configure:3645: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
 then
   ac_cv_func_strcoll_works=yes
 else
@@ -3654,12 +3674,12 @@
 	      getgrgid getgrnam getpwent getpwnam getpwuid
 do
 echo $ac_n "checking for $ac_func""... $ac_c" 1>&6
-echo "configure:3658: checking for $ac_func" >&5
+echo "configure:3678: checking for $ac_func" >&5
 if eval "test \"`echo '$''{'ac_cv_func_$ac_func'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 3663 "configure"
+#line 3683 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func(); below.  */
@@ -3682,7 +3702,7 @@
 
 ; return 0; }
 EOF
-if { (eval echo configure:3686: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
+if { (eval echo configure:3706: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
   rm -rf conftest*
   eval "ac_cv_func_$ac_func=yes"
 else
@@ -3710,12 +3730,12 @@
   for ac_func in dlopen dlerror dlsym dlclose
 do
 echo $ac_n "checking for $ac_func""... $ac_c" 1>&6
-echo "configure:3714: checking for $ac_func" >&5
+echo "configure:3734: checking for $ac_func" >&5
 if eval "test \"`echo '$''{'ac_cv_func_$ac_func'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 3719 "configure"
+#line 3739 "configure"
 #include "confdefs.h"
 /* System header to define __stub macros and hopefully few prototypes,
     which can conflict with char $ac_func(); below.  */
@@ -3738,7 +3758,7 @@
 
 ; return 0; }
 EOF
-if { (eval echo configure:3742: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
+if { (eval echo configure:3762: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest; then
   rm -rf conftest*
   eval "ac_cv_func_$ac_func=yes"
 else
@@ -3766,7 +3786,7 @@
 
 
 echo $ac_n "checking what style of signals to use""... $ac_c" 1>&6
-echo "configure:3770: checking what style of signals to use" >&5
+echo "configure:3790: checking what style of signals to use" >&5
 if test $ac_cv_func_sigaction = yes -a $ac_cv_func_sigprocmask = yes; then
   signals_style=POSIX_SIGNALS
   cat >> confdefs.h <<\EOF
@@ -3799,7 +3819,7 @@
 echo "$ac_t""$signals_style" 1>&6
 
 echo $ac_n "checking where signal.h is located""... $ac_c" 1>&6
-echo "configure:3803: checking where signal.h is located" >&5
+echo "configure:3823: checking where signal.h is located" >&5
 if eval "test \"`echo '$''{'zsh_cv_path_signal_h'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
@@ -3816,7 +3836,7 @@
 SIGNAL_H=$zsh_cv_path_signal_h
 
 echo $ac_n "checking where the RLIMIT macros are located""... $ac_c" 1>&6
-echo "configure:3820: checking where the RLIMIT macros are located" >&5
+echo "configure:3840: checking where the RLIMIT macros are located" >&5
 if eval "test \"`echo '$''{'zsh_cv_path_rlimit_h'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
@@ -3837,7 +3857,7 @@
 
 DEFAULT_RLIM_T=long
 echo $ac_n "checking if rlim_t is quad_t""... $ac_c" 1>&6
-echo "configure:3841: checking if rlim_t is quad_t" >&5
+echo "configure:3861: checking if rlim_t is quad_t" >&5
 if eval "test \"`echo '$''{'zsh_cv_rlim_t_is_quad_t'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
@@ -3845,7 +3865,7 @@
   zsh_cv_rlim_t_is_quad_t=yes
 else
   cat > conftest.$ac_ext <<EOF
-#line 3849 "configure"
+#line 3869 "configure"
 #include "confdefs.h"
 
 #ifdef HAVE_SYS_TIME_H
@@ -3854,7 +3874,7 @@
 #include <sys/resource.h>
 main(){struct rlimit r;exit(sizeof(r.rlim_cur) <= sizeof(long));}
 EOF
-if { (eval echo configure:3858: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
+if { (eval echo configure:3878: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
 then
   zsh_cv_rlim_t_is_quad_t=yes
 else
@@ -3877,7 +3897,7 @@
   DEFAULT_RLIM_T=quad_t
 else
   echo $ac_n "checking if the rlim_t is unsigned""... $ac_c" 1>&6
-echo "configure:3881: checking if the rlim_t is unsigned" >&5
+echo "configure:3901: checking if the rlim_t is unsigned" >&5
 if eval "test \"`echo '$''{'zsh_cv_type_rlim_t_is_unsigned'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
@@ -3885,7 +3905,7 @@
   zsh_cv_type_rlim_t_is_unsigned=no
 else
   cat > conftest.$ac_ext <<EOF
-#line 3889 "configure"
+#line 3909 "configure"
 #include "confdefs.h"
 
 #ifdef HAVE_SYS_TIME_H
@@ -3894,7 +3914,7 @@
 #include <sys/resource.h>
   main(){struct rlimit r;r.rlim_cur=-1;exit(r.rlim_cur<0);}
 EOF
-if { (eval echo configure:3898: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
+if { (eval echo configure:3918: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
 then
   zsh_cv_type_rlim_t_is_unsigned=yes
 else
@@ -3919,12 +3939,12 @@
 fi
 
 echo $ac_n "checking for rlim_t""... $ac_c" 1>&6
-echo "configure:3923: checking for rlim_t" >&5
+echo "configure:3943: checking for rlim_t" >&5
 if eval "test \"`echo '$''{'zsh_cv_type_rlim_t'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 3928 "configure"
+#line 3948 "configure"
 #include "confdefs.h"
 
 #include <sys/types.h>
@@ -3936,7 +3956,7 @@
 rlim_t l;
 ; return 0; }
 EOF
-if { (eval echo configure:3940: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
+if { (eval echo configure:3960: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
   rm -rf conftest*
   zsh_cv_type_rlim_t=yes
 else
@@ -3957,7 +3977,7 @@
 fi
 
 echo $ac_n "checking for /dev/fd filesystem""... $ac_c" 1>&6
-echo "configure:3961: checking for /dev/fd filesystem" >&5
+echo "configure:3981: checking for /dev/fd filesystem" >&5
 if eval "test \"`echo '$''{'zsh_cv_sys_path_dev_fd'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
@@ -3975,7 +3995,7 @@
 fi
 
 echo $ac_n "checking for RFS superroot directory""... $ac_c" 1>&6
-echo "configure:3979: checking for RFS superroot directory" >&5
+echo "configure:3999: checking for RFS superroot directory" >&5
 if eval "test \"`echo '$''{'zsh_cv_sys_superroot'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
@@ -3991,7 +4011,7 @@
 fi
 
 echo $ac_n "checking for NIS""... $ac_c" 1>&6
-echo "configure:3995: checking for NIS" >&5
+echo "configure:4015: checking for NIS" >&5
 if eval "test \"`echo '$''{'zsh_cv_sys_nis'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
@@ -4008,7 +4028,7 @@
 fi
 
 echo $ac_n "checking for NIS+""... $ac_c" 1>&6
-echo "configure:4012: checking for NIS+" >&5
+echo "configure:4032: checking for NIS+" >&5
 if eval "test \"`echo '$''{'zsh_cv_sys_nis_plus'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
@@ -4026,7 +4046,7 @@
 fi
 
 echo $ac_n "checking for utmp file""... $ac_c" 1>&6
-echo "configure:4030: checking for utmp file" >&5
+echo "configure:4050: checking for utmp file" >&5
 if eval "test \"`echo '$''{'zsh_cv_path_utmp'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
@@ -4047,7 +4067,7 @@
 fi
 
 echo $ac_n "checking for wtmp file""... $ac_c" 1>&6
-echo "configure:4051: checking for wtmp file" >&5
+echo "configure:4071: checking for wtmp file" >&5
 if eval "test \"`echo '$''{'zsh_cv_path_wtmp'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
@@ -4068,7 +4088,7 @@
 fi
 
 echo $ac_n "checking for utmpx file""... $ac_c" 1>&6
-echo "configure:4072: checking for utmpx file" >&5
+echo "configure:4092: checking for utmpx file" >&5
 if eval "test \"`echo '$''{'zsh_cv_path_utmpx'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
@@ -4089,7 +4109,7 @@
 fi
 
 echo $ac_n "checking for wtmpx file""... $ac_c" 1>&6
-echo "configure:4093: checking for wtmpx file" >&5
+echo "configure:4113: checking for wtmpx file" >&5
 if eval "test \"`echo '$''{'zsh_cv_path_wtmpx'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
@@ -4111,7 +4131,7 @@
 
 
 echo $ac_n "checking if typeahead needs FIONREAD""... $ac_c" 1>&6
-echo "configure:4115: checking if typeahead needs FIONREAD" >&5
+echo "configure:4135: checking if typeahead needs FIONREAD" >&5
 if eval "test \"`echo '$''{'zsh_cv_sys_clobbers_typeahead'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
@@ -4132,12 +4152,12 @@
 fi
 
 echo $ac_n "checking for brk() prototype in <unistd.h>""... $ac_c" 1>&6
-echo "configure:4136: checking for brk() prototype in <unistd.h>" >&5
+echo "configure:4156: checking for brk() prototype in <unistd.h>" >&5
 if eval "test \"`echo '$''{'zsh_cv_header_unistd_h_brk_proto'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 4141 "configure"
+#line 4161 "configure"
 #include "confdefs.h"
 #include <unistd.h>
 double brk();
@@ -4145,7 +4165,7 @@
 int i;
 ; return 0; }
 EOF
-if { (eval echo configure:4149: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
+if { (eval echo configure:4169: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
   rm -rf conftest*
   zsh_cv_header_unistd_h_brk_proto=no
 else
@@ -4166,12 +4186,12 @@
 fi
 
 echo $ac_n "checking for sbrk() prototype in <unistd.h>""... $ac_c" 1>&6
-echo "configure:4170: checking for sbrk() prototype in <unistd.h>" >&5
+echo "configure:4190: checking for sbrk() prototype in <unistd.h>" >&5
 if eval "test \"`echo '$''{'zsh_cv_header_unistd_h_sbrk_proto'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 4175 "configure"
+#line 4195 "configure"
 #include "confdefs.h"
 #include <unistd.h>
 double sbrk();
@@ -4179,7 +4199,7 @@
 int i;
 ; return 0; }
 EOF
-if { (eval echo configure:4183: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
+if { (eval echo configure:4203: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
   rm -rf conftest*
   zsh_cv_header_unistd_h_sbrk_proto=no
 else
@@ -4202,12 +4222,12 @@
 
 if test "$ac_cv_prog_cc_stdc" != no; then
   echo $ac_n "checking for ioctl prototype in <sys/ioctl.h>""... $ac_c" 1>&6
-echo "configure:4206: checking for ioctl prototype in <sys/ioctl.h>" >&5
+echo "configure:4226: checking for ioctl prototype in <sys/ioctl.h>" >&5
 if eval "test \"`echo '$''{'zsh_cv_header_sys_ioctl_h_ioctl_proto'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
   cat > conftest.$ac_ext <<EOF
-#line 4211 "configure"
+#line 4231 "configure"
 #include "confdefs.h"
 #include <sys/ioctl.h>
    int ioctl(double x);
@@ -4215,7 +4235,7 @@
 int i;
 ; return 0; }
 EOF
-if { (eval echo configure:4219: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
+if { (eval echo configure:4239: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
   rm -rf conftest*
   zsh_cv_header_sys_ioctl_h_ioctl_proto=no
 else
@@ -4237,7 +4257,7 @@
 fi
 
 echo $ac_n "checking if named FIFOs work""... $ac_c" 1>&6
-echo "configure:4241: checking if named FIFOs work" >&5
+echo "configure:4261: checking if named FIFOs work" >&5
 if eval "test \"`echo '$''{'zsh_cv_sys_fifo'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
@@ -4245,7 +4265,7 @@
   zsh_cv_sys_fifo=yes
 else
   cat > conftest.$ac_ext <<EOF
-#line 4249 "configure"
+#line 4269 "configure"
 #include "confdefs.h"
 
 #include <fcntl.h>
@@ -4276,7 +4296,7 @@
 }
 
 EOF
-if { (eval echo configure:4280: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
+if { (eval echo configure:4300: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
 then
   zsh_cv_sys_fifo=yes
 else
@@ -4298,7 +4318,7 @@
 
 fi
 echo $ac_n "checking if echo in /bin/sh interprets escape sequences""... $ac_c" 1>&6
-echo "configure:4302: checking if echo in /bin/sh interprets escape sequences" >&5
+echo "configure:4322: checking if echo in /bin/sh interprets escape sequences" >&5
 if eval "test \"`echo '$''{'zsh_cv_prog_sh_echo_escape'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
@@ -4327,7 +4347,7 @@
 fi
 if test "x$dynamic" = xyes; then
   echo $ac_n "checking if your system use ELF binaries""... $ac_c" 1>&6
-echo "configure:4331: checking if your system use ELF binaries" >&5
+echo "configure:4351: checking if your system use ELF binaries" >&5
 if eval "test \"`echo '$''{'zsh_cv_sys_elf'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
@@ -4335,7 +4355,7 @@
   zsh_cv_sys_elf=yes
 else
   cat > conftest.$ac_ext <<EOF
-#line 4339 "configure"
+#line 4359 "configure"
 #include "confdefs.h"
 /* Test for whether ELF binaries are produced */
 #include <fcntl.h>
@@ -4354,7 +4374,7 @@
 		exit(1); /* fail */
 }
 EOF
-if { (eval echo configure:4358: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
+if { (eval echo configure:4378: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
 then
   zsh_cv_sys_elf=yes
 else
@@ -4397,7 +4417,7 @@
     linux*) EXTRA_LDFLAGS="${EXTRA_LDFLAGS=-rdynamic}" ;;
   esac
   echo $ac_n "checking if your dlsym() needs a leading underscore""... $ac_c" 1>&6
-echo "configure:4401: checking if your dlsym() needs a leading underscore" >&5
+echo "configure:4421: checking if your dlsym() needs a leading underscore" >&5
 if eval "test \"`echo '$''{'zsh_cv_func_dlsym_needs_underscore'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
@@ -4410,7 +4430,7 @@
   zsh_cv_func_dlsym_needs_underscore=no
 else
   cat > conftest.$ac_ext <<EOF
-#line 4414 "configure"
+#line 4434 "configure"
 #include "confdefs.h"
 
 #include <stdio.h>
@@ -4453,7 +4473,7 @@
     exit(0);
 }
 EOF
-if { (eval echo configure:4457: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
+if { (eval echo configure:4477: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
 then
   zsh_cv_func_dlsym_needs_underscore=`cat conftestval`
 else
@@ -4479,7 +4499,7 @@
 
 if test "x$dynamic" = xyes; then
   echo $ac_n "checking if static/shared library linking is broken""... $ac_c" 1>&6
-echo "configure:4483: checking if static/shared library linking is broken" >&5
+echo "configure:4503: checking if static/shared library linking is broken" >&5
 if eval "test \"`echo '$''{'zsh_cv_sys_dynamic_broken'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
@@ -4505,7 +4525,7 @@
 
 else
   cat > conftest.$ac_ext <<EOF
-#line 4509 "configure"
+#line 4529 "configure"
 #include "confdefs.h"
 
 #ifdef HAVE_DLFCN_H
@@ -4540,7 +4560,7 @@
 }
 
 EOF
-if { (eval echo configure:4544: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
+if { (eval echo configure:4564: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
 then
   zsh_cv_sys_dynamic_broken=no
 else
@@ -4565,7 +4585,7 @@
 
 if test "x$dynamic" = xyes; then
   echo $ac_n "checking if name clashes in shared objects are OK""... $ac_c" 1>&6
-echo "configure:4569: checking if name clashes in shared objects are OK" >&5
+echo "configure:4589: checking if name clashes in shared objects are OK" >&5
 if eval "test \"`echo '$''{'zsh_cv_sys_dynamic_clash_ok'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
@@ -4585,7 +4605,7 @@
 
 else
   cat > conftest.$ac_ext <<EOF
-#line 4589 "configure"
+#line 4609 "configure"
 #include "confdefs.h"
 
 #ifdef HAVE_DLFCN_H
@@ -4617,7 +4637,7 @@
 }
 
 EOF
-if { (eval echo configure:4621: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
+if { (eval echo configure:4641: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
 then
   zsh_cv_sys_dynamic_clash_ok=yes
 else
@@ -4644,7 +4664,7 @@
 fi
 
   echo $ac_n "checking for working RTLD_GLOBAL""... $ac_c" 1>&6
-echo "configure:4648: checking for working RTLD_GLOBAL" >&5
+echo "configure:4668: checking for working RTLD_GLOBAL" >&5
 if eval "test \"`echo '$''{'zsh_cv_sys_dynamic_rtld_global'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
@@ -4664,7 +4684,7 @@
 
 else
   cat > conftest.$ac_ext <<EOF
-#line 4668 "configure"
+#line 4688 "configure"
 #include "confdefs.h"
 
 #ifdef HAVE_DLFCN_H
@@ -4695,7 +4715,7 @@
 }
 
 EOF
-if { (eval echo configure:4699: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
+if { (eval echo configure:4719: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
 then
   zsh_cv_sys_dynamic_rtld_global=yes
 else
@@ -4717,7 +4737,7 @@
 
   RTLD_GLOBAL_OK=$zsh_cv_sys_dynamic_rtld_global
   echo $ac_n "checking whether symbols in the executable are available""... $ac_c" 1>&6
-echo "configure:4721: checking whether symbols in the executable are available" >&5
+echo "configure:4741: checking whether symbols in the executable are available" >&5
 if eval "test \"`echo '$''{'zsh_cv_sys_dynamic_execsyms'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
@@ -4736,7 +4756,7 @@
 
 else
   cat > conftest.$ac_ext <<EOF
-#line 4740 "configure"
+#line 4760 "configure"
 #include "confdefs.h"
 
 #ifdef HAVE_DLFCN_H
@@ -4767,7 +4787,7 @@
 int fred () { return 42; }
 
 EOF
-if { (eval echo configure:4771: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
+if { (eval echo configure:4791: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
 then
   zsh_cv_sys_dynamic_execsyms=yes
 else
@@ -4793,7 +4813,7 @@
   fi
   
 echo $ac_n "checking whether executables can be stripped""... $ac_c" 1>&6
-echo "configure:4797: checking whether executables can be stripped" >&5
+echo "configure:4817: checking whether executables can be stripped" >&5
 if eval "test \"`echo '$''{'zsh_cv_sys_dynamic_strip_exe'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
@@ -4815,7 +4835,7 @@
 
 else
   cat > conftest.$ac_ext <<EOF
-#line 4819 "configure"
+#line 4839 "configure"
 #include "confdefs.h"
 
 #ifdef HAVE_DLFCN_H
@@ -4846,7 +4866,7 @@
 int fred () { return 42; }
 
 EOF
-if { (eval echo configure:4850: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
+if { (eval echo configure:4870: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
 then
   zsh_cv_sys_dynamic_strip_exe=yes
 else
@@ -4868,7 +4888,7 @@
 echo "$ac_t""$zsh_cv_sys_dynamic_strip_exe" 1>&6
 
   echo $ac_n "checking whether libraries can be stripped""... $ac_c" 1>&6
-echo "configure:4872: checking whether libraries can be stripped" >&5
+echo "configure:4892: checking whether libraries can be stripped" >&5
 if eval "test \"`echo '$''{'zsh_cv_sys_dynamic_strip_lib'+set}'`\" = set"; then
   echo $ac_n "(cached) $ac_c" 1>&6
 else
@@ -4885,7 +4905,7 @@
 
 else
   cat > conftest.$ac_ext <<EOF
-#line 4889 "configure"
+#line 4909 "configure"
 #include "confdefs.h"
 
 #ifdef HAVE_DLFCN_H
@@ -4914,7 +4934,7 @@
 }
 
 EOF
-if { (eval echo configure:4918: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
+if { (eval echo configure:4938: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; } && test -s conftest && (./conftest; exit) 2>/dev/null
 then
   zsh_cv_sys_dynamic_strip_lib=yes
 else
diff -ru zsh-3.1.5/configure.in zsh-3.1.5-mod/configure.in
--- zsh-3.1.5/configure.in	Fri Oct 30 00:12:25 1998
+++ zsh-3.1.5-mod/configure.in	Thu Mar 11 11:09:24 1999
@@ -182,6 +182,16 @@
 [  --enable-ansi2knr          translate source to K&R C before compiling],
 [ansi2knr="$enableval"], [ansi2knr=default])
 
+dnl Do you want to disable restricted on r* commands
+undefine([resticted-r])dnl
+AC_ARG_ENABLE(resticted-r,
+[  --disable-resticted-r      turn off restricted shell if the invoked command is r*],
+[if test x$enableval = xyes; then
+  AC_DEFINE(RESTRICTED_R)
+fi],
+AC_DEFINE(RESTRICTED_R)
+)
+
 dnl ------------------
 dnl CHECK THE COMPILER
 dnl ------------------
